Einführung — Lino Tera Benutzerhandbuch

# Einführung

## Hauptbildschirm

Der Hauptbildschirm von Lino ist das, wo du nach der Anmeldung landest.

Im Hauptbildschirm gibt es folgende Elemente:

- Das Hauptmenü

- Eine Serie von Schnellverbindungen

- Eventuell Willkommensnachrichten

- das Dashboard

Das Dashboard ist eine Liste von Tabellen, die du Hauptbildschirm jedesmal angezeigt bekommst. Du kannst in den Benutzereinstellungen konfigurieren, was dort steht. Hinter dem Titel einer Tabelle des Dashboards steht oft ein ⏏. Darauf kannst du klicken, um ein Datenfenster auf der betreffenden Tabelle zu öffnen.

## Fenster

Die meisten Menübefehle öffnen ein Fenster. Die meisten Fenster sind Datenfenster, in denen man Daten entweder als Tabellenansicht oder als Vollbildansicht sehen.

Datenfenster haben eine Werkzeugleiste, in der es folgende Elemente gibt:

- Schnellsuche (sh. Suchen in der Datenbank)

- Navigationsbuttons

- Diverse Aktionen (darunter und ).

Um ein Fenster zu schliessen, klicke auf das ❎ in der oberen rechten Ecke des Fensters.

Nach längerem Arbeiten in Lino sind manchmal eine ganze Reihe Fenster geöffnet Um alle Fenster mit einem Klick zu schließen und auf die Startseite zurückzukehren, klicke auf Startseite im Hauptmenü.

## ``Shift`+`Ctrl`+`R``

Gewöhne Dir an, wenn Du morgens zum ersten Mal in Lino reingehst, die Tastenkombination ``Shift`+`Ctrl`+`R`` zu drücken. Dadurch sagst du dem Browser, dass er die Lino-Seite mal komplett neu laden soll.

Auch beim Arbeiten kann es passieren, dass Lino irgendwie nicht wie gewohnt funktioniert, und in so einer Situation kann ein ``Shift`+`Ctrl`+`R`` Wunder bewirken.

Wenn du in einen Kolonnentitel geklickt hast und dadurch die Sortierfolge umdefiniert hast, kannst du das am einfachsten wieder rückgängig machen mit ``Shift`+`Ctrl`+`R``.